@@ -37,6 +37,7 @@ import cgi
 import time
 import urllib
 import urllib2
+import httplib
 import hashlib
 import hmac
 import base64
@@ -169,6 +170,28 @@ class GraphAPI(object):
         """Deletes the object with the given ID from the graph."""
         self.request(id, post_args={"method": "delete"})
 
+    def delete_request(self, user_id, request_id):
+        """Deletes the Request with the given ID for the given user."""
+        conn = httplib.HTTPSConnection('graph.facebook.com')
+
+        url = '/%s_%s?%s' % (
+            request_id,
+            user_id,
+            urllib.urlencode({'access_token': self.access_token}),
+        )
+        conn.request('DELETE', url)
+        response = conn.getresponse()
+        data = response.read()
+
+        response = _parse_json(data)
+        # Raise an error if we got one, but don't not if Facebook just
+        # gave us a Bool value
+        if (response and isinstance(response, dict) and
+            response.get("error")):
+            raise GraphAPIError(response)
+
+        conn.close()
+
     def put_photo(self, image, message=None, album_id=None, **kwargs):
         """Uploads an image using multipart/form-data.
 
